/*
 * Copyright 2013 Red Hat Inc. and/or its affiliates and other contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,  
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.switchyard.security.credential.extractor;

import java.security.Principal;
import java.util.HashSet;
import java.util.Set;

import javax.xml.ws.WebServiceContext;

import org.switchyard.security.credential.Credential;
import org.switchyard.security.credential.PrincipalCredential;

/**
 * WebServiceContextCredentialExtractor.
 *
 * @author David Ward &lt;<a href="mailto:dward@jboss.org">dward@jboss.org</a>&gt; &copy; 2012 Red Hat Inc.
 */
public class WebServiceContextCredentialExtractor implements CredentialExtractor<WebServiceContext> {

    /**
     * Constructs a new WebServiceContextCredentialsExtractor.
     */
    public WebServiceContextCredentialExtractor() {}

    /**
     * {@inheritDoc}
     */
    @Override
    public Set<Credential> extract(WebServiceContext source) {
        Set<Credential> credentials = new HashSet<Credential>();
        if (source != null) {
            Principal userPrincipal = source.getUserPrincipal();
            if (userPrincipal != null) {
                credentials.add(new PrincipalCredential(userPrincipal, true));
            }
        }
        return credentials;
    }

}
